import numpy as np
import matrix_math

Constant = {}
Global = {}
Storage = {}
StorageData = None
StorageDataInv = None

Registers = [0] * 256
TmpRegisters = [0] * 256

DesiredRegs = [137, 193, 59, 168, 164, 129, 35, 165, 159, 193, 12, 170, 90, 182, 156, 214, 172, 62, 59, 106, 175, 186, 174, 231, 160, 56, 67, 221, 44, 68, 90, 244, 192, 123, 140, 245, 218, 169, 58, 8]

def simple_encode(param0):
    return (97 * param0 + 129) % 256

# f1
def f1(x, y):
    foobar = 0
    bar = 1
    barfoo = max(x, y)
    while barfoo >= 1:
        foobar += bar * ((x % 2) ^ (y % 2))
        bar *= 2
        barfoo //= 2
        x //= 2
        y //= 2

    return foobar

# f5
def mod_exp(a, b, c):
    d = 1
    i = 1
    while i <= b:
        d *= a
        d %= c
        i += 1

    return d

# f6
def apply_jukeboxe_data(): # Called like this because the values of "Storage" were loaded from MC Jukeboxes
    s = 0
    for x in range(0, 40):
        for z in range(0, 40):
            m = Storage[f'{x}_0_{z}']
            f = Registers[z]
            s += m * f
            s %= 251

        TmpRegisters[x] = s
        s = 0
    
    for i in range(40):
        Registers[i] = TmpRegisters[i]

def solve_intermediate_registers():
    # Find the Register values that, passed into apply_jukeboxe_data, will result in the desired_regs
    A = []
    for x in range(40):
        row = []
        for z in range(40):
            row.append(Storage[f'{x}_0_{z}'] % 251)
        A.append(row)

    A_inv = matrix_math.mat_inv_mod_251(A)

    target_mod = [t % 251 for t in DesiredRegs]
    initial_registers = matrix_math.mat_vec_mod_251(A_inv, target_mod)
    return initial_registers

def solve_initial_registers():
    intermediate_registers = solve_intermediate_registers()

    def apply_initial_transformation(register_val, register_index):
        var1 = 106
        
        for _ in range(register_index + 1):
            var1 = simple_encode(var1)
        
        register_val = f1(register_val, var1)    
        register_val = mod_exp(6, register_val, 251)

        return register_val

    initial_registers = []
    for i in range(40):
        tested_value = 0
        while True:
            if apply_initial_transformation(tested_value, i) == intermediate_registers[i]:
                initial_registers.append(tested_value)
                print(f"Found initial register value for register {i}: {tested_value}")
                break
            tested_value += 1

    for i in range(40):
        assert apply_initial_transformation(initial_registers[i], i) == intermediate_registers[i]

    return initial_registers

# check_flag
def check_flag():
    var1 = 106

    for i in range(40):
        var1 = simple_encode(var1)
        Registers[i] = f1(Registers[i], var1)
    
    for i in range(40):
        Registers[i] = mod_exp(6, Registers[i], 251)

    apply_jukeboxe_data()

    match = 1
    
    for i in range(40):
        if Registers[i] != DesiredRegs[i]:
            match = 0

    if match == 1:
        print(['give', '@s', 'minecraft:diamond', '4'])
        print(['say', '"You', 'get', '4', 'diamond"'])

# reset
def reset():
    print(['gamerule', 'maxCommandChainLength', '1000000000'])
    Constant['c256'] = 256
    Constant['c97'] = 97
    Constant['c2'] = 2

    for i in range(256):
        Registers[i] = 0
        TmpRegisters[i] = 0
    
    print(['fill', '0', '0', '0', '39', '0', '39', 'minecraft:jukebox', 'destroy'])
    print(['kill', '@e[type=minecraft:item]'])
    print(['forceload', 'add', '0', '0'])
    print(['forceload', 'add', '0', '1'])
    print(['forceload', 'add', '1', '0'])
    print(['forceload', 'add', '1', '1'])
    print(['forceload', 'add', '0', '2'])
    print(['forceload', 'add', '1', '2'])
    print(['forceload', 'add', '2', '0'])
    print(['forceload', 'add', '2', '1'])
    print(['forceload', 'add', '2', '2'])

    Storage['0_0_0'] = 22
    Storage['0_0_1'] = 31
    Storage['0_0_2'] = 224
    Storage['0_0_3'] = 191
    Storage['0_0_4'] = 160
    Storage['0_0_5'] = 143
    Storage['0_0_6'] = 101
    Storage['0_0_7'] = 173
    Storage['0_0_8'] = 255
    Storage['0_0_9'] = 239
    Storage['0_0_10'] = 140
    Storage['0_0_11'] = 63
    Storage['0_0_12'] = 139
    Storage['0_0_13'] = 17
    Storage['0_0_14'] = 22
    Storage['0_0_15'] = 206
    Storage['0_0_16'] = 120
    Storage['0_0_17'] = 114
    Storage['0_0_18'] = 221
    Storage['0_0_19'] = 115
    Storage['0_0_20'] = 198
    Storage['0_0_21'] = 66
    Storage['0_0_22'] = 13
    Storage['0_0_23'] = 181
    Storage['0_0_24'] = 161
    Storage['0_0_25'] = 156
    Storage['0_0_26'] = 111
    Storage['0_0_27'] = 40
    Storage['0_0_28'] = 10
    Storage['0_0_29'] = 5
    Storage['0_0_30'] = 7
    Storage['0_0_31'] = 188
    Storage['0_0_32'] = 155
    Storage['0_0_33'] = 120
    Storage['0_0_34'] = 253
    Storage['0_0_35'] = 103
    Storage['0_0_36'] = 51
    Storage['0_0_37'] = 94
    Storage['0_0_38'] = 72
    Storage['0_0_39'] = 63
    Storage['1_0_0'] = 37
    Storage['1_0_1'] = 6
    Storage['1_0_2'] = 237
    Storage['1_0_3'] = 26
    Storage['1_0_4'] = 169
    Storage['1_0_5'] = 62
    Storage['1_0_6'] = 173
    Storage['1_0_7'] = 163
    Storage['1_0_8'] = 99
    Storage['1_0_9'] = 89
    Storage['1_0_10'] = 130
    Storage['1_0_11'] = 44
    Storage['1_0_12'] = 151
    Storage['1_0_13'] = 121
    Storage['1_0_14'] = 55
    Storage['1_0_15'] = 191
    Storage['1_0_16'] = 221
    Storage['1_0_17'] = 253
    Storage['1_0_18'] = 205
    Storage['1_0_19'] = 232
    Storage['1_0_20'] = 79
    Storage['1_0_21'] = 186
    Storage['1_0_22'] = 1
    Storage['1_0_23'] = 137
    Storage['1_0_24'] = 1
    Storage['1_0_25'] = 104
    Storage['1_0_26'] = 228
    Storage['1_0_27'] = 231
    Storage['1_0_28'] = 200
    Storage['1_0_29'] = 177
    Storage['1_0_30'] = 35
    Storage['1_0_31'] = 37
    Storage['1_0_32'] = 206
    Storage['1_0_33'] = 30
    Storage['1_0_34'] = 132
    Storage['1_0_35'] = 46
    Storage['1_0_36'] = 63
    Storage['1_0_37'] = 115
    Storage['1_0_38'] = 66
    Storage['1_0_39'] = 147
    Storage['2_0_0'] = 39
    Storage['2_0_1'] = 251
    Storage['2_0_2'] = 58
    Storage['2_0_3'] = 168
    Storage['2_0_4'] = 15
    Storage['2_0_5'] = 4
    Storage['2_0_6'] = 190
    Storage['2_0_7'] = 16
    Storage['2_0_8'] = 105
    Storage['2_0_9'] = 190
    Storage['2_0_10'] = 29
    Storage['2_0_11'] = 36
    Storage['2_0_12'] = 121
    Storage['2_0_13'] = 190
    Storage['2_0_14'] = 49
    Storage['2_0_15'] = 66
    Storage['2_0_16'] = 42
    Storage['2_0_17'] = 107
    Storage['2_0_18'] = 160
    Storage['2_0_19'] = 193
    Storage['2_0_20'] = 54
    Storage['2_0_21'] = 156
    Storage['2_0_22'] = 169
    Storage['2_0_23'] = 65
    Storage['2_0_24'] = 37
    Storage['2_0_25'] = 198
    Storage['2_0_26'] = 9
    Storage['2_0_27'] = 80
    Storage['2_0_28'] = 160
    Storage['2_0_29'] = 159
    Storage['2_0_30'] = 73
    Storage['2_0_31'] = 54
    Storage['2_0_32'] = 81
    Storage['2_0_33'] = 157
    Storage['2_0_34'] = 220
    Storage['2_0_35'] = 162
    Storage['2_0_36'] = 158
    Storage['2_0_37'] = 126
    Storage['2_0_38'] = 83
    Storage['2_0_39'] = 130
    Storage['3_0_0'] = 251
    Storage['3_0_1'] = 87
    Storage['3_0_2'] = 166
    Storage['3_0_3'] = 230
    Storage['3_0_4'] = 213
    Storage['3_0_5'] = 64
    Storage['3_0_6'] = 201
    Storage['3_0_7'] = 92
    Storage['3_0_8'] = 220
    Storage['3_0_9'] = 87
    Storage['3_0_10'] = 152
    Storage['3_0_11'] = 221
    Storage['3_0_12'] = 229
    Storage['3_0_13'] = 99
    Storage['3_0_14'] = 212
    Storage['3_0_15'] = 154
    Storage['3_0_16'] = 137
    Storage['3_0_17'] = 152
    Storage['3_0_18'] = 138
    Storage['3_0_19'] = 138
    Storage['3_0_20'] = 56
    Storage['3_0_21'] = 79
    Storage['3_0_22'] = 135
    Storage['3_0_23'] = 94
    Storage['3_0_24'] = 189
    Storage['3_0_25'] = 97
    Storage['3_0_26'] = 129
    Storage['3_0_27'] = 199
    Storage['3_0_28'] = 208
    Storage['3_0_29'] = 16
    Storage['3_0_30'] = 230
    Storage['3_0_31'] = 35
    Storage['3_0_32'] = 3
    Storage['3_0_33'] = 74
    Storage['3_0_34'] = 108
    Storage['3_0_35'] = 92
    Storage['3_0_36'] = 5
    Storage['3_0_37'] = 236
    Storage['3_0_38'] = 7
    Storage['3_0_39'] = 141
    Storage['4_0_0'] = 175
    Storage['4_0_1'] = 62
    Storage['4_0_2'] = 85
    Storage['4_0_3'] = 95
    Storage['4_0_4'] = 117
    Storage['4_0_5'] = 160
    Storage['4_0_6'] = 108
    Storage['4_0_7'] = 93
    Storage['4_0_8'] = 238
    Storage['4_0_9'] = 113
    Storage['4_0_10'] = 197
    Storage['4_0_11'] = 191
    Storage['4_0_12'] = 23
    Storage['4_0_13'] = 92
    Storage['4_0_14'] = 188
    Storage['4_0_15'] = 125
    Storage['4_0_16'] = 49
    Storage['4_0_17'] = 100
    Storage['4_0_18'] = 87
    Storage['4_0_19'] = 48
    Storage['4_0_20'] = 173
    Storage['4_0_21'] = 247
    Storage['4_0_22'] = 230
    Storage['4_0_23'] = 240
    Storage['4_0_24'] = 109
    Storage['4_0_25'] = 34
    Storage['4_0_26'] = 58
    Storage['4_0_27'] = 148
    Storage['4_0_28'] = 232
    Storage['4_0_29'] = 154
    Storage['4_0_30'] = 233
    Storage['4_0_31'] = 34
    Storage['4_0_32'] = 10
    Storage['4_0_33'] = 105
    Storage['4_0_34'] = 105
    Storage['4_0_35'] = 181
    Storage['4_0_36'] = 217
    Storage['4_0_37'] = 136
    Storage['4_0_38'] = 73
    Storage['4_0_39'] = 89
    Storage['5_0_0'] = 223
    Storage['5_0_1'] = 180
    Storage['5_0_2'] = 63
    Storage['5_0_3'] = 11
    Storage['5_0_4'] = 95
    Storage['5_0_5'] = 171
    Storage['5_0_6'] = 252
    Storage['5_0_7'] = 145
    Storage['5_0_8'] = 17
    Storage['5_0_9'] = 171
    Storage['5_0_10'] = 155
    Storage['5_0_11'] = 213
    Storage['5_0_12'] = 223
    Storage['5_0_13'] = 206
    Storage['5_0_14'] = 46
    Storage['5_0_15'] = 178
    Storage['5_0_16'] = 102
    Storage['5_0_17'] = 70
    Storage['5_0_18'] = 219
    Storage['5_0_19'] = 45
    Storage['5_0_20'] = 165
    Storage['5_0_21'] = 48
    Storage['5_0_22'] = 173
    Storage['5_0_23'] = 215
    Storage['5_0_24'] = 125
    Storage['5_0_25'] = 235
    Storage['5_0_26'] = 190
    Storage['5_0_27'] = 12
    Storage['5_0_28'] = 244
    Storage['5_0_29'] = 41
    Storage['5_0_30'] = 189
    Storage['5_0_31'] = 19
    Storage['5_0_32'] = 195
    Storage['5_0_33'] = 63
    Storage['5_0_34'] = 100
    Storage['5_0_35'] = 13
    Storage['5_0_36'] = 43
    Storage['5_0_37'] = 238
    Storage['5_0_38'] = 112
    Storage['5_0_39'] = 25
    Storage['6_0_0'] = 27
    Storage['6_0_1'] = 44
    Storage['6_0_2'] = 71
    Storage['6_0_3'] = 106
    Storage['6_0_4'] = 165
    Storage['6_0_5'] = 208
    Storage['6_0_6'] = 11
    Storage['6_0_7'] = 101
    Storage['6_0_8'] = 162
    Storage['6_0_9'] = 15
    Storage['6_0_10'] = 65
    Storage['6_0_11'] = 254
    Storage['6_0_12'] = 107
    Storage['6_0_13'] = 153
    Storage['6_0_14'] = 176
    Storage['6_0_15'] = 45
    Storage['6_0_16'] = 62
    Storage['6_0_17'] = 87
    Storage['6_0_18'] = 71
    Storage['6_0_19'] = 84
    Storage['6_0_20'] = 226
    Storage['6_0_21'] = 167
    Storage['6_0_22'] = 209
    Storage['6_0_23'] = 94
    Storage['6_0_24'] = 121
    Storage['6_0_25'] = 168
    Storage['6_0_26'] = 230
    Storage['6_0_27'] = 104
    Storage['6_0_28'] = 236
    Storage['6_0_29'] = 212
    Storage['6_0_30'] = 178
    Storage['6_0_31'] = 192
    Storage['6_0_32'] = 240
    Storage['6_0_33'] = 115
    Storage['6_0_34'] = 86
    Storage['6_0_35'] = 65
    Storage['6_0_36'] = 81
    Storage['6_0_37'] = 163
    Storage['6_0_38'] = 141
    Storage['6_0_39'] = 58
    Storage['7_0_0'] = 43
    Storage['7_0_1'] = 234
    Storage['7_0_2'] = 129
    Storage['7_0_3'] = 248
    Storage['7_0_4'] = 62
    Storage['7_0_5'] = 194
    Storage['7_0_6'] = 144
    Storage['7_0_7'] = 145
    Storage['7_0_8'] = 138
    Storage['7_0_9'] = 86
    Storage['7_0_10'] = 223
    Storage['7_0_11'] = 115
    Storage['7_0_12'] = 161
    Storage['7_0_13'] = 166
    Storage['7_0_14'] = 57
    Storage['7_0_15'] = 161
    Storage['7_0_16'] = 118
    Storage['7_0_17'] = 168
    Storage['7_0_18'] = 121
    Storage['7_0_19'] = 85
    Storage['7_0_20'] = 179
    Storage['7_0_21'] = 68
    Storage['7_0_22'] = 117
    Storage['7_0_23'] = 207
    Storage['7_0_24'] = 108
    Storage['7_0_25'] = 34
    Storage['7_0_26'] = 142
    Storage['7_0_27'] = 3
    Storage['7_0_28'] = 221
    Storage['7_0_29'] = 170
    Storage['7_0_30'] = 189
    Storage['7_0_31'] = 29
    Storage['7_0_32'] = 42
    Storage['7_0_33'] = 68
    Storage['7_0_34'] = 200
    Storage['7_0_35'] = 205
    Storage['7_0_36'] = 16
    Storage['7_0_37'] = 221
    Storage['7_0_38'] = 35
    Storage['7_0_39'] = 223
    Storage['8_0_0'] = 181
    Storage['8_0_1'] = 54
    Storage['8_0_2'] = 186
    Storage['8_0_3'] = 172
    Storage['8_0_4'] = 171
    Storage['8_0_5'] = 141
    Storage['8_0_6'] = 47
    Storage['8_0_7'] = 134
    Storage['8_0_8'] = 87
    Storage['8_0_9'] = 22
    Storage['8_0_10'] = 195
    Storage['8_0_11'] = 180
    Storage['8_0_12'] = 65
    Storage['8_0_13'] = 64
    Storage['8_0_14'] = 79
    Storage['8_0_15'] = 24
    Storage['8_0_16'] = 137
    Storage['8_0_17'] = 250
    Storage['8_0_18'] = 102
    Storage['8_0_19'] = 208
    Storage['8_0_20'] = 96
    Storage['8_0_21'] = 144
    Storage['8_0_22'] = 146
    Storage['8_0_23'] = 140
    Storage['8_0_24'] = 227
    Storage['8_0_25'] = 128
    Storage['8_0_26'] = 191
    Storage['8_0_27'] = 87
    Storage['8_0_28'] = 168
    Storage['8_0_29'] = 167
    Storage['8_0_30'] = 240
    Storage['8_0_31'] = 85
    Storage['8_0_32'] = 130
    Storage['8_0_33'] = 104
    Storage['8_0_34'] = 58
    Storage['8_0_35'] = 25
    Storage['8_0_36'] = 203
    Storage['8_0_37'] = 252
    Storage['8_0_38'] = 18
    Storage['8_0_39'] = 85
    Storage['9_0_0'] = 186
    Storage['9_0_1'] = 150
    Storage['9_0_2'] = 21
    Storage['9_0_3'] = 105
    Storage['9_0_4'] = 16
    Storage['9_0_5'] = 170
    Storage['9_0_6'] = 167
    Storage['9_0_7'] = 222
    Storage['9_0_8'] = 149
    Storage['9_0_9'] = 139
    Storage['9_0_10'] = 222
    Storage['9_0_11'] = 205
    Storage['9_0_12'] = 85
    Storage['9_0_13'] = 220
    Storage['9_0_14'] = 186
    Storage['9_0_15'] = 207
    Storage['9_0_16'] = 226
    Storage['9_0_17'] = 102
    Storage['9_0_18'] = 77
    Storage['9_0_19'] = 187
    Storage['9_0_20'] = 13
    Storage['9_0_21'] = 253
    Storage['9_0_22'] = 46
    Storage['9_0_23'] = 244
    Storage['9_0_24'] = 206
    Storage['9_0_25'] = 66
    Storage['9_0_26'] = 129
    Storage['9_0_27'] = 205
    Storage['9_0_28'] = 154
    Storage['9_0_29'] = 66
    Storage['9_0_30'] = 119
    Storage['9_0_31'] = 8
    Storage['9_0_32'] = 254
    Storage['9_0_33'] = 2
    Storage['9_0_34'] = 160
    Storage['9_0_35'] = 74
    Storage['9_0_36'] = 238
    Storage['9_0_37'] = 197
    Storage['9_0_38'] = 160
    Storage['9_0_39'] = 125
    Storage['10_0_0'] = 177
    Storage['10_0_1'] = 2
    Storage['10_0_2'] = 147
    Storage['10_0_3'] = 99
    Storage['10_0_4'] = 14
    Storage['10_0_5'] = 200
    Storage['10_0_6'] = 209
    Storage['10_0_7'] = 58
    Storage['10_0_8'] = 4
    Storage['10_0_9'] = 86
    Storage['10_0_10'] = 214
    Storage['10_0_11'] = 28
    Storage['10_0_12'] = 131
    Storage['10_0_13'] = 136
    Storage['10_0_14'] = 131
    Storage['10_0_15'] = 195
    Storage['10_0_16'] = 85
    Storage['10_0_17'] = 93
    Storage['10_0_18'] = 34
    Storage['10_0_19'] = 40
    Storage['10_0_20'] = 183
    Storage['10_0_21'] = 96
    Storage['10_0_22'] = 144
    Storage['10_0_23'] = 101
    Storage['10_0_24'] = 55
    Storage['10_0_25'] = 15
    Storage['10_0_26'] = 25
    Storage['10_0_27'] = 26
    Storage['10_0_28'] = 166
    Storage['10_0_29'] = 10
    Storage['10_0_30'] = 200
    Storage['10_0_31'] = 53
    Storage['10_0_32'] = 21
    Storage['10_0_33'] = 71
    Storage['10_0_34'] = 192
    Storage['10_0_35'] = 206
    Storage['10_0_36'] = 200
    Storage['10_0_37'] = 21
    Storage['10_0_38'] = 17
    Storage['10_0_39'] = 66
    Storage['11_0_0'] = 1
    Storage['11_0_1'] = 246
    Storage['11_0_2'] = 244
    Storage['11_0_3'] = 136
    Storage['11_0_4'] = 107
    Storage['11_0_5'] = 231
    Storage['11_0_6'] = 215
    Storage['11_0_7'] = 7
    Storage['11_0_8'] = 231
    Storage['11_0_9'] = 53
    Storage['11_0_10'] = 220
    Storage['11_0_11'] = 10
    Storage['11_0_12'] = 233
    Storage['11_0_13'] = 127
    Storage['11_0_14'] = 61
    Storage['11_0_15'] = 8
    Storage['11_0_16'] = 223
    Storage['11_0_17'] = 84
    Storage['11_0_18'] = 170
    Storage['11_0_19'] = 129
    Storage['11_0_20'] = 6
    Storage['11_0_21'] = 208
    Storage['11_0_22'] = 152
    Storage['11_0_23'] = 236
    Storage['11_0_24'] = 54
    Storage['11_0_25'] = 155
    Storage['11_0_26'] = 161
    Storage['11_0_27'] = 85
    Storage['11_0_28'] = 25
    Storage['11_0_29'] = 15
    Storage['11_0_30'] = 207
    Storage['11_0_31'] = 107
    Storage['11_0_32'] = 239
    Storage['11_0_33'] = 208
    Storage['11_0_34'] = 126
    Storage['11_0_35'] = 56
    Storage['11_0_36'] = 30
    Storage['11_0_37'] = 83
    Storage['11_0_38'] = 34
    Storage['11_0_39'] = 23
    Storage['12_0_0'] = 79
    Storage['12_0_1'] = 204
    Storage['12_0_2'] = 45
    Storage['12_0_3'] = 215
    Storage['12_0_4'] = 29
    Storage['12_0_5'] = 240
    Storage['12_0_6'] = 167
    Storage['12_0_7'] = 63
    Storage['12_0_8'] = 67
    Storage['12_0_9'] = 230
    Storage['12_0_10'] = 20
    Storage['12_0_11'] = 132
    Storage['12_0_12'] = 44
    Storage['12_0_13'] = 4
    Storage['12_0_14'] = 189
    Storage['12_0_15'] = 135
    Storage['12_0_16'] = 126
    Storage['12_0_17'] = 63
    Storage['12_0_18'] = 255
    Storage['12_0_19'] = 162
    Storage['12_0_20'] = 130
    Storage['12_0_21'] = 244
    Storage['12_0_22'] = 158
    Storage['12_0_23'] = 222
    Storage['12_0_24'] = 158
    Storage['12_0_25'] = 12
    Storage['12_0_26'] = 53
    Storage['12_0_27'] = 48
    Storage['12_0_28'] = 113
    Storage['12_0_29'] = 205
    Storage['12_0_30'] = 9
    Storage['12_0_31'] = 233
    Storage['12_0_32'] = 91
    Storage['12_0_33'] = 91
    Storage['12_0_34'] = 195
    Storage['12_0_35'] = 38
    Storage['12_0_36'] = 58
    Storage['12_0_37'] = 246
    Storage['12_0_38'] = 210
    Storage['12_0_39'] = 187
    Storage['13_0_0'] = 38
    Storage['13_0_1'] = 164
    Storage['13_0_2'] = 215
    Storage['13_0_3'] = 80
    Storage['13_0_4'] = 117
    Storage['13_0_5'] = 92
    Storage['13_0_6'] = 187
    Storage['13_0_7'] = 131
    Storage['13_0_8'] = 100
    Storage['13_0_9'] = 217
    Storage['13_0_10'] = 8
    Storage['13_0_11'] = 160
    Storage['13_0_12'] = 126
    Storage['13_0_13'] = 189
    Storage['13_0_14'] = 4
    Storage['13_0_15'] = 46
    Storage['13_0_16'] = 113
    Storage['13_0_17'] = 51
    Storage['13_0_18'] = 111
    Storage['13_0_19'] = 205
    Storage['13_0_20'] = 201
    Storage['13_0_21'] = 50
    Storage['13_0_22'] = 89
    Storage['13_0_23'] = 37
    Storage['13_0_24'] = 28
    Storage['13_0_25'] = 92
    Storage['13_0_26'] = 38
    Storage['13_0_27'] = 40
    Storage['13_0_28'] = 131
    Storage['13_0_29'] = 111
    Storage['13_0_30'] = 55
    Storage['13_0_31'] = 113
    Storage['13_0_32'] = 221
    Storage['13_0_33'] = 51
    Storage['13_0_34'] = 125
    Storage['13_0_35'] = 214
    Storage['13_0_36'] = 28
    Storage['13_0_37'] = 97
    Storage['13_0_38'] = 104
    Storage['13_0_39'] = 7
    Storage['14_0_0'] = 16
    Storage['14_0_1'] = 208
    Storage['14_0_2'] = 78
    Storage['14_0_3'] = 189
    Storage['14_0_4'] = 123
    Storage['14_0_5'] = 145
    Storage['14_0_6'] = 51
    Storage['14_0_7'] = 128
    Storage['14_0_8'] = 119
    Storage['14_0_9'] = 28
    Storage['14_0_10'] = 23
    Storage['14_0_11'] = 220
    Storage['14_0_12'] = 123
    Storage['14_0_13'] = 218
    Storage['14_0_14'] = 186
    Storage['14_0_15'] = 244
    Storage['14_0_16'] = 196
    Storage['14_0_17'] = 112
    Storage['14_0_18'] = 89
    Storage['14_0_19'] = 172
    Storage['14_0_20'] = 212
    Storage['14_0_21'] = 221
    Storage['14_0_22'] = 188
    Storage['14_0_23'] = 10
    Storage['14_0_24'] = 175
    Storage['14_0_25'] = 16
    Storage['14_0_26'] = 185
    Storage['14_0_27'] = 21
    Storage['14_0_28'] = 228
    Storage['14_0_29'] = 7
    Storage['14_0_30'] = 136
    Storage['14_0_31'] = 246
    Storage['14_0_32'] = 130
    Storage['14_0_33'] = 124
    Storage['14_0_34'] = 180
    Storage['14_0_35'] = 168
    Storage['14_0_36'] = 233
    Storage['14_0_37'] = 198
    Storage['14_0_38'] = 204
    Storage['14_0_39'] = 150
    Storage['15_0_0'] = 237
    Storage['15_0_1'] = 10
    Storage['15_0_2'] = 109
    Storage['15_0_3'] = 189
    Storage['15_0_4'] = 163
    Storage['15_0_5'] = 105
    Storage['15_0_6'] = 179
    Storage['15_0_7'] = 123
    Storage['15_0_8'] = 17
    Storage['15_0_9'] = 58
    Storage['15_0_10'] = 230
    Storage['15_0_11'] = 14
    Storage['15_0_12'] = 205
    Storage['15_0_13'] = 76
    Storage['15_0_14'] = 86
    Storage['15_0_15'] = 10
    Storage['15_0_16'] = 113
    Storage['15_0_17'] = 25
    Storage['15_0_18'] = 205
    Storage['15_0_19'] = 56
    Storage['15_0_20'] = 237
    Storage['15_0_21'] = 134
    Storage['15_0_22'] = 167
    Storage['15_0_23'] = 118
    Storage['15_0_24'] = 227
    Storage['15_0_25'] = 153
    Storage['15_0_26'] = 156
    Storage['15_0_27'] = 173
    Storage['15_0_28'] = 237
    Storage['15_0_29'] = 13
    Storage['15_0_30'] = 145
    Storage['15_0_31'] = 104
    Storage['15_0_32'] = 121
    Storage['15_0_33'] = 59
    Storage['15_0_34'] = 95
    Storage['15_0_35'] = 57
    Storage['15_0_36'] = 133
    Storage['15_0_37'] = 29
    Storage['15_0_38'] = 21
    Storage['15_0_39'] = 246
    Storage['16_0_0'] = 154
    Storage['16_0_1'] = 207
    Storage['16_0_2'] = 232
    Storage['16_0_3'] = 255
    Storage['16_0_4'] = 84
    Storage['16_0_5'] = 106
    Storage['16_0_6'] = 243
    Storage['16_0_7'] = 65
    Storage['16_0_8'] = 224
    Storage['16_0_9'] = 69
    Storage['16_0_10'] = 229
    Storage['16_0_11'] = 17
    Storage['16_0_12'] = 47
    Storage['16_0_13'] = 30
    Storage['16_0_14'] = 16
    Storage['16_0_15'] = 31
    Storage['16_0_16'] = 197
    Storage['16_0_17'] = 139
    Storage['16_0_18'] = 211
    Storage['16_0_19'] = 3
    Storage['16_0_20'] = 73
    Storage['16_0_21'] = 79
    Storage['16_0_22'] = 24
    Storage['16_0_23'] = 201
    Storage['16_0_24'] = 212
    Storage['16_0_25'] = 172
    Storage['16_0_26'] = 239
    Storage['16_0_27'] = 183
    Storage['16_0_28'] = 242
    Storage['16_0_29'] = 231
    Storage['16_0_30'] = 72
    Storage['16_0_31'] = 113
    Storage['16_0_32'] = 163
    Storage['16_0_33'] = 187
    Storage['16_0_34'] = 71
    Storage['16_0_35'] = 250
    Storage['16_0_36'] = 102
    Storage['16_0_37'] = 161
    Storage['16_0_38'] = 31
    Storage['16_0_39'] = 152
    Storage['17_0_0'] = 95
    Storage['17_0_1'] = 24
    Storage['17_0_2'] = 249
    Storage['17_0_3'] = 71
    Storage['17_0_4'] = 129
    Storage['17_0_5'] = 15
    Storage['17_0_6'] = 170
    Storage['17_0_7'] = 89
    Storage['17_0_8'] = 252
    Storage['17_0_9'] = 207
    Storage['17_0_10'] = 236
    Storage['17_0_11'] = 32
    Storage['17_0_12'] = 16
    Storage['17_0_13'] = 32
    Storage['17_0_14'] = 139
    Storage['17_0_15'] = 207
    Storage['17_0_16'] = 152
    Storage['17_0_17'] = 81
    Storage['17_0_18'] = 214
    Storage['17_0_19'] = 167
    Storage['17_0_20'] = 94
    Storage['17_0_21'] = 85
    Storage['17_0_22'] = 247
    Storage['17_0_23'] = 138
    Storage['17_0_24'] = 226
    Storage['17_0_25'] = 50
    Storage['17_0_26'] = 248
    Storage['17_0_27'] = 124
    Storage['17_0_28'] = 183
    Storage['17_0_29'] = 70
    Storage['17_0_30'] = 9
    Storage['17_0_31'] = 3
    Storage['17_0_32'] = 240
    Storage['17_0_33'] = 190
    Storage['17_0_34'] = 221
    Storage['17_0_35'] = 59
    Storage['17_0_36'] = 21
    Storage['17_0_37'] = 94
    Storage['17_0_38'] = 123
    Storage['17_0_39'] = 17
    Storage['18_0_0'] = 167
    Storage['18_0_1'] = 183
    Storage['18_0_2'] = 249
    Storage['18_0_3'] = 72
    Storage['18_0_4'] = 228
    Storage['18_0_5'] = 96
    Storage['18_0_6'] = 45
    Storage['18_0_7'] = 58
    Storage['18_0_8'] = 63
    Storage['18_0_9'] = 188
    Storage['18_0_10'] = 80
    Storage['18_0_11'] = 72
    Storage['18_0_12'] = 176
    Storage['18_0_13'] = 52
    Storage['18_0_14'] = 156
    Storage['18_0_15'] = 148
    Storage['18_0_16'] = 72
    Storage['18_0_17'] = 185
    Storage['18_0_18'] = 171
    Storage['18_0_19'] = 121
    Storage['18_0_20'] = 38
    Storage['18_0_21'] = 238
    Storage['18_0_22'] = 40
    Storage['18_0_23'] = 190
    Storage['18_0_24'] = 34
    Storage['18_0_25'] = 31
    Storage['18_0_26'] = 191
    Storage['18_0_27'] = 9
    Storage['18_0_28'] = 246
    Storage['18_0_29'] = 46
    Storage['18_0_30'] = 88
    Storage['18_0_31'] = 155
    Storage['18_0_32'] = 128
    Storage['18_0_33'] = 36
    Storage['18_0_34'] = 87
    Storage['18_0_35'] = 73
    Storage['18_0_36'] = 158
    Storage['18_0_37'] = 172
    Storage['18_0_38'] = 38
    Storage['18_0_39'] = 244
    Storage['19_0_0'] = 16
    Storage['19_0_1'] = 218
    Storage['19_0_2'] = 10
    Storage['19_0_3'] = 36
    Storage['19_0_4'] = 147
    Storage['19_0_5'] = 253
    Storage['19_0_6'] = 206
    Storage['19_0_7'] = 2
    Storage['19_0_8'] = 2
    Storage['19_0_9'] = 253
    Storage['19_0_10'] = 199
    Storage['19_0_11'] = 123
    Storage['19_0_12'] = 29
    Storage['19_0_13'] = 208
    Storage['19_0_14'] = 180
    Storage['19_0_15'] = 76
    Storage['19_0_16'] = 254
    Storage['19_0_17'] = 186
    Storage['19_0_18'] = 150
    Storage['19_0_19'] = 119
    Storage['19_0_20'] = 20
    Storage['19_0_21'] = 1
    Storage['19_0_22'] = 186
    Storage['19_0_23'] = 45
    Storage['19_0_24'] = 45
    Storage['19_0_25'] = 44
    Storage['19_0_26'] = 209
    Storage['19_0_27'] = 175
    Storage['19_0_28'] = 12
    Storage['19_0_29'] = 169
    Storage['19_0_30'] = 182
    Storage['19_0_31'] = 109
    Storage['19_0_32'] = 153
    Storage['19_0_33'] = 58
    Storage['19_0_34'] = 229
    Storage['19_0_35'] = 15
    Storage['19_0_36'] = 189
    Storage['19_0_37'] = 13
    Storage['19_0_38'] = 100
    Storage['19_0_39'] = 49
    Storage['20_0_0'] = 132
    Storage['20_0_1'] = 219
    Storage['20_0_2'] = 69
    Storage['20_0_3'] = 29
    Storage['20_0_4'] = 19
    Storage['20_0_5'] = 49
    Storage['20_0_6'] = 46
    Storage['20_0_7'] = 140
    Storage['20_0_8'] = 189
    Storage['20_0_9'] = 10
    Storage['20_0_10'] = 130
    Storage['20_0_11'] = 35
    Storage['20_0_12'] = 77
    Storage['20_0_13'] = 167
    Storage['20_0_14'] = 68
    Storage['20_0_15'] = 106
    Storage['20_0_16'] = 193
    Storage['20_0_17'] = 5
    Storage['20_0_18'] = 31
    Storage['20_0_19'] = 16
    Storage['20_0_20'] = 134
    Storage['20_0_21'] = 181
    Storage['20_0_22'] = 14
    Storage['20_0_23'] = 118
    Storage['20_0_24'] = 106
    Storage['20_0_25'] = 70
    Storage['20_0_26'] = 15
    Storage['20_0_27'] = 44
    Storage['20_0_28'] = 1
    Storage['20_0_29'] = 28
    Storage['20_0_30'] = 223
    Storage['20_0_31'] = 121
    Storage['20_0_32'] = 63
    Storage['20_0_33'] = 121
    Storage['20_0_34'] = 121
    Storage['20_0_35'] = 113
    Storage['20_0_36'] = 179
    Storage['20_0_37'] = 133
    Storage['20_0_38'] = 203
    Storage['20_0_39'] = 74
    Storage['21_0_0'] = 87
    Storage['21_0_1'] = 53
    Storage['21_0_2'] = 122
    Storage['21_0_3'] = 225
    Storage['21_0_4'] = 219
    Storage['21_0_5'] = 30
    Storage['21_0_6'] = 96
    Storage['21_0_7'] = 110
    Storage['21_0_8'] = 219
    Storage['21_0_9'] = 187
    Storage['21_0_10'] = 179
    Storage['21_0_11'] = 19
    Storage['21_0_12'] = 85
    Storage['21_0_13'] = 97
    Storage['21_0_14'] = 80
    Storage['21_0_15'] = 195
    Storage['21_0_16'] = 138
    Storage['21_0_17'] = 183
    Storage['21_0_18'] = 31
    Storage['21_0_19'] = 249
    Storage['21_0_20'] = 1
    Storage['21_0_21'] = 57
    Storage['21_0_22'] = 112
    Storage['21_0_23'] = 72
    Storage['21_0_24'] = 176
    Storage['21_0_25'] = 51
    Storage['21_0_26'] = 137
    Storage['21_0_27'] = 223
    Storage['21_0_28'] = 160
    Storage['21_0_29'] = 45
    Storage['21_0_30'] = 132
    Storage['21_0_31'] = 233
    Storage['21_0_32'] = 205
    Storage['21_0_33'] = 242
    Storage['21_0_34'] = 84
    Storage['21_0_35'] = 41
    Storage['21_0_36'] = 15
    Storage['21_0_37'] = 37
    Storage['21_0_38'] = 125
    Storage['21_0_39'] = 180
    Storage['22_0_0'] = 10
    Storage['22_0_1'] = 60
    Storage['22_0_2'] = 250
    Storage['22_0_3'] = 242
    Storage['22_0_4'] = 88
    Storage['22_0_5'] = 252
    Storage['22_0_6'] = 147
    Storage['22_0_7'] = 71
    Storage['22_0_8'] = 215
    Storage['22_0_9'] = 131
    Storage['22_0_10'] = 70
    Storage['22_0_11'] = 104
    Storage['22_0_12'] = 75
    Storage['22_0_13'] = 134
    Storage['22_0_14'] = 35
    Storage['22_0_15'] = 107
    Storage['22_0_16'] = 19
    Storage['22_0_17'] = 116
    Storage['22_0_18'] = 150
    Storage['22_0_19'] = 133
    Storage['22_0_20'] = 144
    Storage['22_0_21'] = 201
    Storage['22_0_22'] = 56
    Storage['22_0_23'] = 249
    Storage['22_0_24'] = 27
    Storage['22_0_25'] = 254
    Storage['22_0_26'] = 1
    Storage['22_0_27'] = 87
    Storage['22_0_28'] = 155
    Storage['22_0_29'] = 135
    Storage['22_0_30'] = 67
    Storage['22_0_31'] = 25
    Storage['22_0_32'] = 144
    Storage['22_0_33'] = 180
    Storage['22_0_34'] = 68
    Storage['22_0_35'] = 226
    Storage['22_0_36'] = 167
    Storage['22_0_37'] = 137
    Storage['22_0_38'] = 93
    Storage['22_0_39'] = 49
    Storage['23_0_0'] = 25
    Storage['23_0_1'] = 5
    Storage['23_0_2'] = 165
    Storage['23_0_3'] = 16
    Storage['23_0_4'] = 199
    Storage['23_0_5'] = 92
    Storage['23_0_6'] = 100
    Storage['23_0_7'] = 52
    Storage['23_0_8'] = 42
    Storage['23_0_9'] = 63
    Storage['23_0_10'] = 49
    Storage['23_0_11'] = 118
    Storage['23_0_12'] = 75
    Storage['23_0_13'] = 67
    Storage['23_0_14'] = 232
    Storage['23_0_15'] = 216
    Storage['23_0_16'] = 218
    Storage['23_0_17'] = 177
    Storage['23_0_18'] = 199
    Storage['23_0_19'] = 205
    Storage['23_0_20'] = 194
    Storage['23_0_21'] = 187
    Storage['23_0_22'] = 132
    Storage['23_0_23'] = 226
    Storage['23_0_24'] = 151
    Storage['23_0_25'] = 126
    Storage['23_0_26'] = 22
    Storage['23_0_27'] = 23
    Storage['23_0_28'] = 205
    Storage['23_0_29'] = 157
    Storage['23_0_30'] = 31
    Storage['23_0_31'] = 180
    Storage['23_0_32'] = 70
    Storage['23_0_33'] = 38
    Storage['23_0_34'] = 51
    Storage['23_0_35'] = 54
    Storage['23_0_36'] = 178
    Storage['23_0_37'] = 38
    Storage['23_0_38'] = 130
    Storage['23_0_39'] = 220
    Storage['24_0_0'] = 179
    Storage['24_0_1'] = 243
    Storage['24_0_2'] = 147
    Storage['24_0_3'] = 70
    Storage['24_0_4'] = 25
    Storage['24_0_5'] = 124
    Storage['24_0_6'] = 81
    Storage['24_0_7'] = 255
    Storage['24_0_8'] = 114
    Storage['24_0_9'] = 153
    Storage['24_0_10'] = 211
    Storage['24_0_11'] = 94
    Storage['24_0_12'] = 5
    Storage['24_0_13'] = 248
    Storage['24_0_14'] = 19
    Storage['24_0_15'] = 186
    Storage['24_0_16'] = 156
    Storage['24_0_17'] = 225
    Storage['24_0_18'] = 105
    Storage['24_0_19'] = 169
    Storage['24_0_20'] = 217
    Storage['24_0_21'] = 47
    Storage['24_0_22'] = 176
    Storage['24_0_23'] = 47
    Storage['24_0_24'] = 203
    Storage['24_0_25'] = 190
    Storage['24_0_26'] = 71
    Storage['24_0_27'] = 71
    Storage['24_0_28'] = 13
    Storage['24_0_29'] = 133
    Storage['24_0_30'] = 170
    Storage['24_0_31'] = 139
    Storage['24_0_32'] = 53
    Storage['24_0_33'] = 113
    Storage['24_0_34'] = 11
    Storage['24_0_35'] = 248
    Storage['24_0_36'] = 70
    Storage['24_0_37'] = 0
    Storage['24_0_38'] = 122
    Storage['24_0_39'] = 79
    Storage['25_0_0'] = 28
    Storage['25_0_1'] = 248
    Storage['25_0_2'] = 39
    Storage['25_0_3'] = 0
    Storage['25_0_4'] = 168
    Storage['25_0_5'] = 193
    Storage['25_0_6'] = 136
    Storage['25_0_7'] = 51
    Storage['25_0_8'] = 40
    Storage['25_0_9'] = 29
    Storage['25_0_10'] = 88
    Storage['25_0_11'] = 51
    Storage['25_0_12'] = 161
    Storage['25_0_13'] = 152
    Storage['25_0_14'] = 147
    Storage['25_0_15'] = 113
    Storage['25_0_16'] = 203
    Storage['25_0_17'] = 204
    Storage['25_0_18'] = 67
    Storage['25_0_19'] = 118
    Storage['25_0_20'] = 235
    Storage['25_0_21'] = 192
    Storage['25_0_22'] = 224
    Storage['25_0_23'] = 90
    Storage['25_0_24'] = 120
    Storage['25_0_25'] = 251
    Storage['25_0_26'] = 63
    Storage['25_0_27'] = 58
    Storage['25_0_28'] = 205
    Storage['25_0_29'] = 163
    Storage['25_0_30'] = 0
    Storage['25_0_31'] = 26
    Storage['25_0_32'] = 246
    Storage['25_0_33'] = 108
    Storage['25_0_34'] = 57
    Storage['25_0_35'] = 43
    Storage['25_0_36'] = 53
    Storage['25_0_37'] = 79
    Storage['25_0_38'] = 193
    Storage['25_0_39'] = 107
    Storage['26_0_0'] = 137
    Storage['26_0_1'] = 169
    Storage['26_0_2'] = 40
    Storage['26_0_3'] = 18
    Storage['26_0_4'] = 185
    Storage['26_0_5'] = 159
    Storage['26_0_6'] = 120
    Storage['26_0_7'] = 192
    Storage['26_0_8'] = 144
    Storage['26_0_9'] = 206
    Storage['26_0_10'] = 181
    Storage['26_0_11'] = 44
    Storage['26_0_12'] = 107
    Storage['26_0_13'] = 115
    Storage['26_0_14'] = 78
    Storage['26_0_15'] = 132
    Storage['26_0_16'] = 220
    Storage['26_0_17'] = 199
    Storage['26_0_18'] = 20
    Storage['26_0_19'] = 141
    Storage['26_0_20'] = 45
    Storage['26_0_21'] = 252
    Storage['26_0_22'] = 213
    Storage['26_0_23'] = 189
    Storage['26_0_24'] = 23
    Storage['26_0_25'] = 229
    Storage['26_0_26'] = 67
    Storage['26_0_27'] = 31
    Storage['26_0_28'] = 131
    Storage['26_0_29'] = 214
    Storage['26_0_30'] = 9
    Storage['26_0_31'] = 45
    Storage['26_0_32'] = 55
    Storage['26_0_33'] = 148
    Storage['26_0_34'] = 198
    Storage['26_0_35'] = 184
    Storage['26_0_36'] = 119
    Storage['26_0_37'] = 16
    Storage['26_0_38'] = 187
    Storage['26_0_39'] = 215
    Storage['27_0_0'] = 121
    Storage['27_0_1'] = 93
    Storage['27_0_2'] = 23
    Storage['27_0_3'] = 246
    Storage['27_0_4'] = 210
    Storage['27_0_5'] = 234
    Storage['27_0_6'] = 60
    Storage['27_0_7'] = 143
    Storage['27_0_8'] = 216
    Storage['27_0_9'] = 121
    Storage['27_0_10'] = 18
    Storage['27_0_11'] = 70
    Storage['27_0_12'] = 102
    Storage['27_0_13'] = 180
    Storage['27_0_14'] = 19
    Storage['27_0_15'] = 7
    Storage['27_0_16'] = 139
    Storage['27_0_17'] = 199
    Storage['27_0_18'] = 68
    Storage['27_0_19'] = 144
    Storage['27_0_20'] = 88
    Storage['27_0_21'] = 22
    Storage['27_0_22'] = 42
    Storage['27_0_23'] = 56
    Storage['27_0_24'] = 241
    Storage['27_0_25'] = 233
    Storage['27_0_26'] = 224
    Storage['27_0_27'] = 122
    Storage['27_0_28'] = 173
    Storage['27_0_29'] = 197
    Storage['27_0_30'] = 104
    Storage['27_0_31'] = 107
    Storage['27_0_32'] = 202
    Storage['27_0_33'] = 34
    Storage['27_0_34'] = 14
    Storage['27_0_35'] = 193
    Storage['27_0_36'] = 40
    Storage['27_0_37'] = 123
    Storage['27_0_38'] = 51
    Storage['27_0_39'] = 173
    Storage['28_0_0'] = 10
    Storage['28_0_1'] = 240
    Storage['28_0_2'] = 51
    Storage['28_0_3'] = 83
    Storage['28_0_4'] = 156
    Storage['28_0_5'] = 41
    Storage['28_0_6'] = 97
    Storage['28_0_7'] = 207
    Storage['28_0_8'] = 11
    Storage['28_0_9'] = 255
    Storage['28_0_10'] = 160
    Storage['28_0_11'] = 124
    Storage['28_0_12'] = 135
    Storage['28_0_13'] = 108
    Storage['28_0_14'] = 125
    Storage['28_0_15'] = 213
    Storage['28_0_16'] = 137
    Storage['28_0_17'] = 159
    Storage['28_0_18'] = 188
    Storage['28_0_19'] = 203
    Storage['28_0_20'] = 16
    Storage['28_0_21'] = 208
    Storage['28_0_22'] = 115
    Storage['28_0_23'] = 53
    Storage['28_0_24'] = 118
    Storage['28_0_25'] = 142
    Storage['28_0_26'] = 253
    Storage['28_0_27'] = 171
    Storage['28_0_28'] = 65
    Storage['28_0_29'] = 170
    Storage['28_0_30'] = 251
    Storage['28_0_31'] = 154
    Storage['28_0_32'] = 12
    Storage['28_0_33'] = 191
    Storage['28_0_34'] = 62
    Storage['28_0_35'] = 204
    Storage['28_0_36'] = 3
    Storage['28_0_37'] = 246
    Storage['28_0_38'] = 62
    Storage['28_0_39'] = 21
    Storage['29_0_0'] = 168
    Storage['29_0_1'] = 182
    Storage['29_0_2'] = 29
    Storage['29_0_3'] = 169
    Storage['29_0_4'] = 32
    Storage['29_0_5'] = 132
    Storage['29_0_6'] = 161
    Storage['29_0_7'] = 175
    Storage['29_0_8'] = 142
    Storage['29_0_9'] = 190
    Storage['29_0_10'] = 237
    Storage['29_0_11'] = 43
    Storage['29_0_12'] = 215
    Storage['29_0_13'] = 81
    Storage['29_0_14'] = 204
    Storage['29_0_15'] = 151
    Storage['29_0_16'] = 251
    Storage['29_0_17'] = 37
    Storage['29_0_18'] = 73
    Storage['29_0_19'] = 242
    Storage['29_0_20'] = 18
    Storage['29_0_21'] = 71
    Storage['29_0_22'] = 43
    Storage['29_0_23'] = 140
    Storage['29_0_24'] = 28
    Storage['29_0_25'] = 41
    Storage['29_0_26'] = 236
    Storage['29_0_27'] = 229
    Storage['29_0_28'] = 232
    Storage['29_0_29'] = 132
    Storage['29_0_30'] = 79
    Storage['29_0_31'] = 175
    Storage['29_0_32'] = 34
    Storage['29_0_33'] = 132
    Storage['29_0_34'] = 121
    Storage['29_0_35'] = 22
    Storage['29_0_36'] = 49
    Storage['29_0_37'] = 223
    Storage['29_0_38'] = 184
    Storage['29_0_39'] = 220
    Storage['30_0_0'] = 186
    Storage['30_0_1'] = 230
    Storage['30_0_2'] = 180
    Storage['30_0_3'] = 255
    Storage['30_0_4'] = 213
    Storage['30_0_5'] = 179
    Storage['30_0_6'] = 254
    Storage['30_0_7'] = 40
    Storage['30_0_8'] = 46
    Storage['30_0_9'] = 123
    Storage['30_0_10'] = 46
    Storage['30_0_11'] = 250
    Storage['30_0_12'] = 246
    Storage['30_0_13'] = 226
    Storage['30_0_14'] = 115
    Storage['30_0_15'] = 198
    Storage['30_0_16'] = 217
    Storage['30_0_17'] = 248
    Storage['30_0_18'] = 126
    Storage['30_0_19'] = 79
    Storage['30_0_20'] = 208
    Storage['30_0_21'] = 192
    Storage['30_0_22'] = 166
    Storage['30_0_23'] = 71
    Storage['30_0_24'] = 16
    Storage['30_0_25'] = 124
    Storage['30_0_26'] = 180
    Storage['30_0_27'] = 214
    Storage['30_0_28'] = 67
    Storage['30_0_29'] = 202
    Storage['30_0_30'] = 1
    Storage['30_0_31'] = 252
    Storage['30_0_32'] = 8
    Storage['30_0_33'] = 86
    Storage['30_0_34'] = 247
    Storage['30_0_35'] = 234
    Storage['30_0_36'] = 35
    Storage['30_0_37'] = 8
    Storage['30_0_38'] = 113
    Storage['30_0_39'] = 235
    Storage['31_0_0'] = 146
    Storage['31_0_1'] = 205
    Storage['31_0_2'] = 202
    Storage['31_0_3'] = 240
    Storage['31_0_4'] = 86
    Storage['31_0_5'] = 84
    Storage['31_0_6'] = 227
    Storage['31_0_7'] = 74
    Storage['31_0_8'] = 241
    Storage['31_0_9'] = 208
    Storage['31_0_10'] = 76
    Storage['31_0_11'] = 251
    Storage['31_0_12'] = 223
    Storage['31_0_13'] = 85
    Storage['31_0_14'] = 38
    Storage['31_0_15'] = 56
    Storage['31_0_16'] = 99
    Storage['31_0_17'] = 163
    Storage['31_0_18'] = 209
    Storage['31_0_19'] = 215
    Storage['31_0_20'] = 123
    Storage['31_0_21'] = 158
    Storage['31_0_22'] = 183
    Storage['31_0_23'] = 230
    Storage['31_0_24'] = 123
    Storage['31_0_25'] = 245
    Storage['31_0_26'] = 43
    Storage['31_0_27'] = 216
    Storage['31_0_28'] = 79
    Storage['31_0_29'] = 237
    Storage['31_0_30'] = 33
    Storage['31_0_31'] = 90
    Storage['31_0_32'] = 80
    Storage['31_0_33'] = 19
    Storage['31_0_34'] = 223
    Storage['31_0_35'] = 13
    Storage['31_0_36'] = 75
    Storage['31_0_37'] = 134
    Storage['31_0_38'] = 90
    Storage['31_0_39'] = 101
    Storage['32_0_0'] = 218
    Storage['32_0_1'] = 15
    Storage['32_0_2'] = 55
    Storage['32_0_3'] = 79
    Storage['32_0_4'] = 147
    Storage['32_0_5'] = 13
    Storage['32_0_6'] = 33
    Storage['32_0_7'] = 170
    Storage['32_0_8'] = 42
    Storage['32_0_9'] = 187
    Storage['32_0_10'] = 198
    Storage['32_0_11'] = 99
    Storage['32_0_12'] = 84
    Storage['32_0_13'] = 191
    Storage['32_0_14'] = 85
    Storage['32_0_15'] = 68
    Storage['32_0_16'] = 26
    Storage['32_0_17'] = 98
    Storage['32_0_18'] = 196
    Storage['32_0_19'] = 126
    Storage['32_0_20'] = 68
    Storage['32_0_21'] = 169
    Storage['32_0_22'] = 48
    Storage['32_0_23'] = 225
    Storage['32_0_24'] = 75
    Storage['32_0_25'] = 91
    Storage['32_0_26'] = 218
    Storage['32_0_27'] = 27
    Storage['32_0_28'] = 204
    Storage['32_0_29'] = 15
    Storage['32_0_30'] = 78
    Storage['32_0_31'] = 93
    Storage['32_0_32'] = 196
    Storage['32_0_33'] = 17
    Storage['32_0_34'] = 50
    Storage['32_0_35'] = 193
    Storage['32_0_36'] = 146
    Storage['32_0_37'] = 145
    Storage['32_0_38'] = 243
    Storage['32_0_39'] = 14
    Storage['33_0_0'] = 105
    Storage['33_0_1'] = 107
    Storage['33_0_2'] = 115
    Storage['33_0_3'] = 139
    Storage['33_0_4'] = 62
    Storage['33_0_5'] = 65
    Storage['33_0_6'] = 119
    Storage['33_0_7'] = 43
    Storage['33_0_8'] = 91
    Storage['33_0_9'] = 142
    Storage['33_0_10'] = 222
    Storage['33_0_11'] = 133
    Storage['33_0_12'] = 19
    Storage['33_0_13'] = 113
    Storage['33_0_14'] = 77
    Storage['33_0_15'] = 253
    Storage['33_0_16'] = 96
    Storage['33_0_17'] = 40
    Storage['33_0_18'] = 253
    Storage['33_0_19'] = 125
    Storage['33_0_20'] = 48
    Storage['33_0_21'] = 138
    Storage['33_0_22'] = 157
    Storage['33_0_23'] = 128
    Storage['33_0_24'] = 144
    Storage['33_0_25'] = 225
    Storage['33_0_26'] = 178
    Storage['33_0_27'] = 12
    Storage['33_0_28'] = 104
    Storage['33_0_29'] = 231
    Storage['33_0_30'] = 129
    Storage['33_0_31'] = 59
    Storage['33_0_32'] = 134
    Storage['33_0_33'] = 102
    Storage['33_0_34'] = 224
    Storage['33_0_35'] = 216
    Storage['33_0_36'] = 185
    Storage['33_0_37'] = 110
    Storage['33_0_38'] = 104
    Storage['33_0_39'] = 77
    Storage['34_0_0'] = 70
    Storage['34_0_1'] = 200
    Storage['34_0_2'] = 5
    Storage['34_0_3'] = 118
    Storage['34_0_4'] = 184
    Storage['34_0_5'] = 188
    Storage['34_0_6'] = 114
    Storage['34_0_7'] = 228
    Storage['34_0_8'] = 218
    Storage['34_0_9'] = 13
    Storage['34_0_10'] = 134
    Storage['34_0_11'] = 199
    Storage['34_0_12'] = 225
    Storage['34_0_13'] = 74
    Storage['34_0_14'] = 171
    Storage['34_0_15'] = 209
    Storage['34_0_16'] = 35
    Storage['34_0_17'] = 8
    Storage['34_0_18'] = 116
    Storage['34_0_19'] = 86
    Storage['34_0_20'] = 65
    Storage['34_0_21'] = 160
    Storage['34_0_22'] = 184
    Storage['34_0_23'] = 173
    Storage['34_0_24'] = 130
    Storage['34_0_25'] = 13
    Storage['34_0_26'] = 70
    Storage['34_0_27'] = 126
    Storage['34_0_28'] = 141
    Storage['34_0_29'] = 153
    Storage['34_0_30'] = 110
    Storage['34_0_31'] = 78
    Storage['34_0_32'] = 68
    Storage['34_0_33'] = 51
    Storage['34_0_34'] = 104
    Storage['34_0_35'] = 37
    Storage['34_0_36'] = 12
    Storage['34_0_37'] = 187
    Storage['34_0_38'] = 97
    Storage['34_0_39'] = 206
    Storage['35_0_0'] = 7
    Storage['35_0_1'] = 213
    Storage['35_0_2'] = 143
    Storage['35_0_3'] = 135
    Storage['35_0_4'] = 45
    Storage['35_0_5'] = 82
    Storage['35_0_6'] = 60
    Storage['35_0_7'] = 97
    Storage['35_0_8'] = 195
    Storage['35_0_9'] = 38
    Storage['35_0_10'] = 54
    Storage['35_0_11'] = 23
    Storage['35_0_12'] = 166
    Storage['35_0_13'] = 50
    Storage['35_0_14'] = 24
    Storage['35_0_15'] = 170
    Storage['35_0_16'] = 86
    Storage['35_0_17'] = 40
    Storage['35_0_18'] = 227
    Storage['35_0_19'] = 239
    Storage['35_0_20'] = 58
    Storage['35_0_21'] = 242
    Storage['35_0_22'] = 160
    Storage['35_0_23'] = 32
    Storage['35_0_24'] = 36
    Storage['35_0_25'] = 182
    Storage['35_0_26'] = 103
    Storage['35_0_27'] = 51
    Storage['35_0_28'] = 222
    Storage['35_0_29'] = 115
    Storage['35_0_30'] = 166
    Storage['35_0_31'] = 94
    Storage['35_0_32'] = 144
    Storage['35_0_33'] = 70
    Storage['35_0_34'] = 145
    Storage['35_0_35'] = 126
    Storage['35_0_36'] = 143
    Storage['35_0_37'] = 30
    Storage['35_0_38'] = 122
    Storage['35_0_39'] = 51
    Storage['36_0_0'] = 224
    Storage['36_0_1'] = 100
    Storage['36_0_2'] = 172
    Storage['36_0_3'] = 240
    Storage['36_0_4'] = 58
    Storage['36_0_5'] = 75
    Storage['36_0_6'] = 14
    Storage['36_0_7'] = 225
    Storage['36_0_8'] = 85
    Storage['36_0_9'] = 77
    Storage['36_0_10'] = 146
    Storage['36_0_11'] = 92
    Storage['36_0_12'] = 99
    Storage['36_0_13'] = 105
    Storage['36_0_14'] = 208
    Storage['36_0_15'] = 244
    Storage['36_0_16'] = 254
    Storage['36_0_17'] = 16
    Storage['36_0_18'] = 162
    Storage['36_0_19'] = 155
    Storage['36_0_20'] = 140
    Storage['36_0_21'] = 149
    Storage['36_0_22'] = 28
    Storage['36_0_23'] = 115
    Storage['36_0_24'] = 219
    Storage['36_0_25'] = 84
    Storage['36_0_26'] = 172
    Storage['36_0_27'] = 159
    Storage['36_0_28'] = 207
    Storage['36_0_29'] = 152
    Storage['36_0_30'] = 235
    Storage['36_0_31'] = 76
    Storage['36_0_32'] = 95
    Storage['36_0_33'] = 90
    Storage['36_0_34'] = 199
    Storage['36_0_35'] = 208
    Storage['36_0_36'] = 28
    Storage['36_0_37'] = 160
    Storage['36_0_38'] = 216
    Storage['36_0_39'] = 170
    Storage['37_0_0'] = 166
    Storage['37_0_1'] = 6
    Storage['37_0_2'] = 251
    Storage['37_0_3'] = 49
    Storage['37_0_4'] = 91
    Storage['37_0_5'] = 42
    Storage['37_0_6'] = 101
    Storage['37_0_7'] = 204
    Storage['37_0_8'] = 51
    Storage['37_0_9'] = 14
    Storage['37_0_10'] = 148
    Storage['37_0_11'] = 9
    Storage['37_0_12'] = 17
    Storage['37_0_13'] = 90
    Storage['37_0_14'] = 192
    Storage['37_0_15'] = 250
    Storage['37_0_16'] = 157
    Storage['37_0_17'] = 27
    Storage['37_0_18'] = 152
    Storage['37_0_19'] = 49
    Storage['37_0_20'] = 90
    Storage['37_0_21'] = 31
    Storage['37_0_22'] = 218
    Storage['37_0_23'] = 10
    Storage['37_0_24'] = 192
    Storage['37_0_25'] = 11
    Storage['37_0_26'] = 87
    Storage['37_0_27'] = 7
    Storage['37_0_28'] = 195
    Storage['37_0_29'] = 112
    Storage['37_0_30'] = 10
    Storage['37_0_31'] = 216
    Storage['37_0_32'] = 3
    Storage['37_0_33'] = 252
    Storage['37_0_34'] = 29
    Storage['37_0_35'] = 194
    Storage['37_0_36'] = 214
    Storage['37_0_37'] = 169
    Storage['37_0_38'] = 71
    Storage['37_0_39'] = 37
    Storage['38_0_0'] = 137
    Storage['38_0_1'] = 132
    Storage['38_0_2'] = 120
    Storage['38_0_3'] = 218
    Storage['38_0_4'] = 251
    Storage['38_0_5'] = 123
    Storage['38_0_6'] = 210
    Storage['38_0_7'] = 249
    Storage['38_0_8'] = 196
    Storage['38_0_9'] = 63
    Storage['38_0_10'] = 191
    Storage['38_0_11'] = 33
    Storage['38_0_12'] = 185
    Storage['38_0_13'] = 148
    Storage['38_0_14'] = 6
    Storage['38_0_15'] = 101
    Storage['38_0_16'] = 201
    Storage['38_0_17'] = 10
    Storage['38_0_18'] = 176
    Storage['38_0_19'] = 139
    Storage['38_0_20'] = 129
    Storage['38_0_21'] = 111
    Storage['38_0_22'] = 32
    Storage['38_0_23'] = 152
    Storage['38_0_24'] = 38
    Storage['38_0_25'] = 230
    Storage['38_0_26'] = 82
    Storage['38_0_27'] = 81
    Storage['38_0_28'] = 37
    Storage['38_0_29'] = 230
    Storage['38_0_30'] = 192
    Storage['38_0_31'] = 161
    Storage['38_0_32'] = 216
    Storage['38_0_33'] = 106
    Storage['38_0_34'] = 201
    Storage['38_0_35'] = 167
    Storage['38_0_36'] = 115
    Storage['38_0_37'] = 5
    Storage['38_0_38'] = 51
    Storage['38_0_39'] = 164
    Storage['39_0_0'] = 130
    Storage['39_0_1'] = 8
    Storage['39_0_2'] = 19
    Storage['39_0_3'] = 5
    Storage['39_0_4'] = 183
    Storage['39_0_5'] = 252
    Storage['39_0_6'] = 84
    Storage['39_0_7'] = 85
    Storage['39_0_8'] = 201
    Storage['39_0_9'] = 129
    Storage['39_0_10'] = 11
    Storage['39_0_11'] = 135
    Storage['39_0_12'] = 167
    Storage['39_0_13'] = 10
    Storage['39_0_14'] = 180
    Storage['39_0_15'] = 184
    Storage['39_0_16'] = 117
    Storage['39_0_17'] = 75
    Storage['39_0_18'] = 181
    Storage['39_0_19'] = 152
    Storage['39_0_20'] = 194
    Storage['39_0_21'] = 16
    Storage['39_0_22'] = 197
    Storage['39_0_23'] = 169
    Storage['39_0_24'] = 182
    Storage['39_0_25'] = 167
    Storage['39_0_26'] = 248
    Storage['39_0_27'] = 71
    Storage['39_0_28'] = 180
    Storage['39_0_29'] = 62
    Storage['39_0_30'] = 190
    Storage['39_0_31'] = 140
    Storage['39_0_32'] = 246
    Storage['39_0_33'] = 252
    Storage['39_0_34'] = 209
    Storage['39_0_35'] = 129
    Storage['39_0_36'] = 146
    Storage['39_0_37'] = 30
    Storage['39_0_38'] = 96
    Storage['39_0_39'] = 159

    # 2D Array version of Storage
    global StorageData
    StorageData = [[0] * 40] * 40
    for i in range(40):
        for j in range(40):
            StorageData[i][j] = Storage[str(i) + "_0_" + str(j)]

    print(['"Finished', 'reloading"'])

reset()
solution = solve_initial_registers()
print(''.join([chr(solution[i]) for i in range(40)]))
for i in range(40):
    Registers[i] = solution[i]

check_flag()
